import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import ReactDropdown from 'react-dropdown';
import {
  scaleLinear,
  extent,
  scaleSqrt,
  max,
  histogram as bin,
  sum,
  nest,
  scaleOrdinal
} from 'd3';
import { useDataMap } from './useDataMap';
import { useDataViews } from './useDataViews';
import { Marks } from './Marks';
import { Dropdown } from './Dropdown'

const width = 960
const menuHeight = 100
const height = 500
const margin = { top: 20, right: 90, bottom: 200, left: 90 };

const attributes = [
	{ value: 'India', label: 'India'},
  { value: 'United States', label: 'United States'},
  { value: 'China', label: 'China'},
]


const getLabel = value => {
  for (let i = 0; i < attributes.length; i++) {
    if (attributes[i].value === value) {
      return attributes[i].label;
    }
  }
};



const App = () => {

  const mapData = useDataMap();
  const viewData = useDataViews();

  const initialAttribute = 'All';
  const [selectedValue, setSelectedValue] = useState(initialAttribute);
  const countryValue = d => d[attributes];
    
  if (!mapData || !viewData) {
    return <pre>Loading...</pre>;
  }                       
  

  
  const lng = d => d.Lng;
  const lat = d => d.Lat;
  const country = d => d.Countries;
  const views = d => d.TotalViews;
  const sizeValue = d => d.views;
  const maxRadius = 20;
  const sizeScale = scaleSqrt()
    .domain([0, max(viewData, sizeValue)])
    .range([0, maxRadius]);

  
  return (
    <>
     <svg width={width} height={height}>
      <Marks
        mapData={mapData}
        viewData = {viewData}
        lng={lng}
        lat={lat}
        views={views}
        country={country}
        sizeScale={sizeScale}
        sizeValue={sizeValue}
 />
    </svg>
     <div className="menus-container">
				<span className="dropdown-label">Choose a country: </span>
			  <ReactDropdown
        options={attributes}
        id = "x-select"       
        value={selectedValue}      
        onChange={({ value }) => setSelectedValue(countryValue(value))}
       // onSelectedValueChange={setSelectedValue}
          />
    </div>
      </>
  );

};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
